Method: OpenSearch::API::Tasks::Actions#list
- Defined in:
- lib/opensearch/api/actions/tasks/list.rb
#list(arguments = {}) ⇒ Object
Returns a list of tasks. This functionality is Experimental and may be changed or removed completely in a future release. OpenSearch will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/opensearch/api/actions/tasks/list.rb', line 47 def list(arguments = {}) headers = arguments.delete(:headers) || {} arguments = arguments.clone method = OpenSearch::API::HTTP_GET path = "_tasks" params = Utils.__validate_and_extract_params arguments, ParamsRegistry.get(__method__) body = nil perform_request(method, path, params, body, headers).body end |